@@ -7,38 +7,37 @@ require Class::DBI::Loader::Generic;
 use base qw(Class::DBI::Loader::Generic);
 use vars qw($VERSION);
 
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 sub _croak { require Carp; Carp::croak(@_); }
 sub _load_classes {
     my $self = shift;
     my $dbh = DBI->connect(@{$self->_datasource}) or _croak($DBI::errstr);
-#    foreach my $table($dbh->tables( {'TABLE_TYPE' => 'TABLE'} ) {
-    foreach my $table($dbh->tables) {
-        if ($table !~ /SYSCAT/ && $table !~ /SYSIBM/ && $table !~ /SYSSTAT/) {
-          my $sth = $dbh->prepare(<<"SQL");
+    foreach my $table($dbh->tables( { 'TABLE_TYPE' => 'TABLE' } ) ) {
+      my $sth = $dbh->prepare(<<"SQL");
 SELECT c.COLNAME FROM SYSCAT.KEYCOLUSE kc, SYSCAT.TABCONST tc,  SYSCAT.COLUMNS c
 WHERE kc.CONSTNAME=tc.CONSTNAME AND kc.TABSCHEMA=tc.TABSCHEMA
 AND kc.TABNAME=tc.TABNAME AND kc.TABSCHEMA=c.TABSCHEMA AND
 kc.TABNAME=c.TABNAME AND kc.COLNAME=c.COLNAME AND kc.TABSCHEMA = ? AND
 kc.TABNAME = ? AND tc.TYPE = 'P' ORDER BY kc.COLSEQ
 SQL
-          my ($tabschema,$tbl) = split '\.', $table;
-          $sth->execute( uc($tabschema), uc($tbl) );
-          my $primaries = $sth->fetchall_arrayref;
-          $sth->finish;
-          my ( @primary );
-          map { push @primary, $_ } @$primaries;
+      my ($tabschema,$tbl) = split '\.', $table;
+      $sth->execute( uc($tabschema), uc($tbl) );
+      my $primaries = $sth->fetchall_arrayref;
+      $sth->finish;
+      my ( @primary );
+      map { push @primary, $_ } @$primaries;
 
-          if ( @primary ) {
-	    my $class = $self->_table2class($table);
-	    no strict 'refs';
-	    @{"$class\::ISA"} = qw(Class::DBI::DB2);
-	    $class->set_db(Main => @{$self->_datasource});
-	    $class->set_up_table($table);
-	    $self->{CLASSES}->{$table} = $class;
-          }
-        }
+      if ( @primary ) {
+        my $class = $self->_table2class(lc($table));
+	no strict 'refs';
+	@{"$class\::ISA"} = qw(Class::DBI::DB2);
+	$class->set_db(Main => @{$self->_datasource});
+        my $alias = $table;
+        $alias =~ s/\./_/;
+	$class->set_up_table(lc($table),$alias);
+	$self->{CLASSES}->{$table} = $class;
+      }
     }
     $dbh->disconnect;
 }
